Name:           docker-compose
Version:        1.29.2
Release:        %mkrel 4
Summary:        Multi-container orchestration for Docker
Group:          System/Configuration
License:        ASL 2.0
URL:            https://www.docker.com/
Source0:        https://files.pythonhosted.org/packages/source/d/%{name}/%{name}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(docker) >= 4.2.1
BuildRequires:  python3dist(websocket-client)
BuildRequires:  python3dist(texttable)
BuildRequires:  python3dist(requests)
BuildRequires:  python3dist(pyyaml)
BuildRequires:  python3dist(docopt)

Requires:       python3dist(paramiko)
Requires:       python3dist(repoze.lru)
Requires:       python3dist(setuptools)
Requires:       python3dist(texttable)

# docker-compose is compatible with fig and is a simple rename.
Provides:       fig = %{version}-%{release}
Obsoletes:      fig < 1.0.0-4

%description
Multi-container orchestration for Docker

Docker-compose allows you to:
- Define your application's environment with Docker so it can be reproduced
  anywhere.
- Define the services that make up your app so they can be run together in an
  isolated environment.
- Run 'docker-compose up', and docker-compose will start and run your entire
  app.

%prep
%setup -q

# Drop bundled egg-info
rm -rf docker_compose.egg-info/

# Remove dependency version constraints not relevant
sed -e 's/, < [0-9.]\+//' -i setup.py

%build
%py3_build

cat > README.urpmi <<EOF
Docker-compose will require modifications with shorewall

The modifications will be described in

https://gist.github.com/lukasnellen/20761a20286f32efc396e207d986295d

However interface uses FORMAT1 which requires a - in the broadcast field

dock 	docker0		-      physical=docker+,routeback=1
dock 	br		-      physical=br-+,routeback=1
EOF

%install
%py3_install

%files
%doc CHANGES.md CONTRIBUTING.md README.md SWARM.md README.urpmi
%license LICENSE
%{_bindir}/%{name}
# Upstream uses an underscore here
%{python3_sitelib}/docker_compose*
%{python3_sitelib}/compose*


%changelog
* Sun Oct 02 2022 joequant <joequant> 1.29.2-4.mga9
+ Revision: 1894094
- add message about interaction with shorewall

* Tue Mar 29 2022 umeabot <umeabot> 1.29.2-3.mga9
+ Revision: 1832187
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 1.29.2-2.mga9
+ Revision: 1782758
- Rebuild for python-3.10

* Mon Oct 25 2021 bcornec <bcornec> 1.29.2-1.mga9
+ Revision: 1752868
- Update to upstream docker-compose 1.29.2

* Sun Apr 11 2021 joequant <joequant> 1.29.0-1.mga9
+ Revision: 1714727
- update to 1.29

* Sat Mar 27 2021 tv <tv> 1.26.2-2.mga9
+ Revision: 1710979
- Rebuild for python 3.9

* Mon Aug 24 2020 bcornec <bcornec> 1.26.2-1.mga8
+ Revision: 1618397
- Update to upstream docker-compose 1.26.2

* Tue Jun 30 2020 akien <akien> 1.26.0-2.mga8
+ Revision: 1600617
- Add requires on paramiko (docker-compose fails otherwise)

* Tue Jun 09 2020 joequant <joequant> 1.26.0-1.mga8
+ Revision: 1591260
- update to 1.26.0

* Sun Feb 16 2020 umeabot <umeabot> 1.24.1-3.mga8
+ Revision: 1533404
- Mageia 8 Mass Rebuild

* Sat Sep 21 2019 daviddavid <daviddavid> 1.24.1-2.mga8
+ Revision: 1444156
- rebuild for python3.8

* Wed Sep 04 2019 bcornec <bcornec> 1.24.1-1.mga8
+ Revision: 1437228
- update to upstream 1.24.1 and only use python3

* Tue Apr 23 2019 wally <wally> 1.23.2-3.mga7
+ Revision: 1395017
- add dep version fix from Fedora (mga#24706)
- use sources from pypi

* Tue Jan 01 2019 bcornec <bcornec> 1.23.2-2.mga7
+ Revision: 1348449
- Fix setup.py to allow more recent requests

* Tue Jan 01 2019 bcornec <bcornec> 1.23.2-1.mga7
+ Revision: 1348142
- Update to upstream docker-compose 1.23.2

* Tue Nov 06 2018 bcornec <bcornec> 1.23.1-1.mga7
+ Revision: 1328627
- update to upstream docker-compose 1.23.1

* Sun Oct 21 2018 bcornec <bcornec> 1.23.0rc3-1.mga7
+ Revision: 1323440
- update to upstream docker-compose 1.23.0-rc3 and fix requests dependency

* Mon Oct 15 2018 bcornec <bcornec> 1.23.0rc2-4.mga7
+ Revision: 1320388
- Try to fix a version dependency issue for pyYAML

* Fri Oct 12 2018 bcornec <bcornec> 1.23.0rc2-3.mga7
+ Revision: 1319748
+ rebuild (emptylog)

* Wed Oct 10 2018 bcornec <bcornec> 1.23.0rc2-2.mga7
+ Revision: 1319265
- Update to upstream docker-compose 1.23.0-rc2

* Thu Sep 20 2018 umeabot <umeabot> 1.19.0-2.mga7
+ Revision: 1278040
- Mageia 7 Mass Rebuild

* Tue Mar 06 2018 bcornec <bcornec> 1.19.0-1.mga7
+ Revision: 1206948
- quiet sha1
- update to upstream docker-compose 1.19

* Tue Aug 08 2017 daviddavid <daviddavid> 1.15.0-1.mga7
+ Revision: 1138950
- new version: 1.15.0
- obsoletes properly fig
- remove useless requirements that are already auto-requis
- use new python macros

* Fri Jun 02 2017 bcornec <bcornec> 1.13.0-2.mga6
+ Revision: 1105763
- Change dependency from python-docker-py to the new python-docker replacing it

* Thu May 11 2017 bcornec <bcornec> 1.13.0-1.mga6
+ Revision: 1100154
- update to upstream 0.13.0 docker-compose

* Thu Nov 24 2016 bcornec <bcornec> 1.9.0-1.mga6
+ Revision: 1069586
- update to upstream docker-compose 1.9.0
- Upate to upstream 1.9.0

* Mon May 23 2016 bcornec <bcornec> 1.7.1-3.mga6
+ Revision: 1018026
- Remove inexistant tests
- docker isn't restricted to x86_64 so is this one as well

* Mon May 23 2016 bcornec <bcornec> 1.7.1-2.mga6
+ Revision: 1017979
- docker-compose is only available on x86_64 as docker
- Fix group
- import docker-compose, based on a Fedora spec file
- Created package structure for docker-compose.

